@@ -62,6 +62,9 @@ class TrelloConnection(object):
     def get_list(self, list_id):
         return List(self, list_id)
 
+    def get_checklist(self, checklist_id):
+        return Checklist(self, checklist_id)
+
     def get_member(self, member_id):
         return Member(self, member_id)
 
@@ -263,13 +266,15 @@ class Card(LazyTrello, Closable):
     board = ObjectField('idBoard', 'Board')
     list = ObjectField('idList', 'List')
 
+    checklists = ListField('idChecklists','Checklist')
     members = ListField('idMembers', 'Member')
 
 
 class Checklist(LazyTrello):
 
     _prefix = '/checklists/'
-    checkitems = Field()
+
+    checkItems = SubList('CheckItem')
     name = Field()
     board = ObjectField('idBoard', 'Board')
     cards = SubList('Card')
@@ -280,6 +285,13 @@ class Checklist(LazyTrello):
     # TODO: Figure out why checklists have a /cards/ subpath in the docs.  How
     # could one checklist belong to multiple cards?
 
+class CheckItem(LazyTrello):
+    
+    _prefix = '/checkItems/'
+
+    name = Field()
+    pos = Field()
+    type = Field()
 
 class List(LazyTrello, Closable):
 
